//
//  GLPluginInterface.h
//  MapProgram
//
//  Created by Jeffrey Early on 6/28/06.
//  Copyright 2006 Early Innovation. All rights reserved.
//

#import <Cocoa/Cocoa.h>
#import "GLExporter.h"
#import "GLMapDataSource.h"
#import "GLSpatialObjectController.h"
#import "GLSpatialObjectControllerBase.h"
#import <GLGeometryKit/GLSpatialObject.h>

/* GLPluginProtocol */

// This protocol defines the root plugin API set that every plugin needs to
// respond to.
//
// This protocol is derived from http://cocoadevcentral.com/articles/000068.php
//
// The idea here is that a given bundle can be responsible for multiple plugins.
// The setup also gives this bundle the ability to let two different plugins use
// the same resources.

@protocol GLPlugin

typedef enum {
	kGLExporterType,
	kGLMapDataSourceType,
	kGLSpatialObjectControllerType,
} GLPluginType;

// Called before plugin instances are requested. If NO is returned, no plugins will be requested
+ (BOOL) initializePluginBundle;

+ (void) terminatePluginBundle;

// returns the plugins for a given plugin type.
+ (NSEnumerator*) pluginsForType: (GLPluginType) pluginType;

@end
